@@ -41,7 +41,7 @@ use namespace::autoclean;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.8.0'; # VERSION
+our $VERSION = 'v0.8.1'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -61,49 +61,8 @@ use IPC::System::Simple ();
 use Path::Tiny 0.070    ();
 use Perl::Version       ();
 
-#   Explicitly require all the plugins to let them appear in the metadata.
-use Dist::Zilla::Plugin::AutoPrereqs                        ();
-use Dist::Zilla::Plugin::CheckChangesHasContent             ();
-use Dist::Zilla::Plugin::CheckExtraTests                    ();
-use Dist::Zilla::Plugin::CheckPrereqsIndexed                ();
-use Dist::Zilla::Plugin::ConfirmRelease                     ();
-use Dist::Zilla::Plugin::Hook                       0.007   ();     # We need `Hook::Releaser`.
-use Dist::Zilla::Plugin::Manifest::Read                     ();
-use Dist::Zilla::Plugin::Manifest::Write                    ();
-use Dist::Zilla::Plugin::MetaJSON                           ();
-use Dist::Zilla::Plugin::MetaProvides::Package              ();
-use Dist::Zilla::Plugin::MetaResources::Template            ();
-use Dist::Zilla::Plugin::MetaTests                          ();
-use Dist::Zilla::Plugin::MetaYAML                           ();
-use Dist::Zilla::Plugin::MinimumPerl                        ();
-use Dist::Zilla::Plugin::ModuleBuildTiny                    ();
-use Dist::Zilla::Plugin::MojibakeTests                      ();
-use Dist::Zilla::Plugin::NextRelease                        ();
-use Dist::Zilla::Plugin::OurPkgVersion                      ();
-use Dist::Zilla::Plugin::PodCoverageTests                   ();
-use Dist::Zilla::Plugin::PodSyntaxTests                     ();
-use Dist::Zilla::Plugin::Prereqs::AuthorDeps                ();
-use Dist::Zilla::Plugin::SurgicalPodWeaver                  ();
-use Dist::Zilla::Plugin::Templates                  v0.5.0  ();     ## no critic ( ProhibitVersionStrings )
-    # ^ Need including `Dist::Zilla::FIle` objects.
-use Dist::Zilla::Plugin::Test::Compile                      ();
-use Dist::Zilla::Plugin::Test::CPAN::Changes                ();
-use Dist::Zilla::Plugin::Test::CPAN::Meta::JSON             ();
-use Dist::Zilla::Plugin::Test::DistManifest                 ();
-use Dist::Zilla::Plugin::Test::EOL                          ();
-use Dist::Zilla::Plugin::Test::Kwalitee                     ();
-use Dist::Zilla::Plugin::Test::MinimumVersion               ();
-use Dist::Zilla::Plugin::Test::NewVersion                   ();
-use Dist::Zilla::Plugin::Test::NoTabs                       ();
-use Dist::Zilla::Plugin::Test::Perl::Critic                 ();
-use Dist::Zilla::Plugin::Test::Pod::No404s                  ();
-use Dist::Zilla::Plugin::Test::PodSpelling                  ();
-use Dist::Zilla::Plugin::TestRelease                        ();
-use Dist::Zilla::Plugin::Test::Version                      ();
-use Dist::Zilla::Plugin::UploadToCPAN                       ();
-
-#   One more implicitly required module.
-use Pod::Weaver::PluginBundle::Author::VDB                  ();
+#   Implicitly required module.
+use Pod::Weaver::PluginBundle::Author::VDB ();
 
 # --------------------------------------------------------------------------------------------------
 
@@ -151,19 +110,7 @@ has copying => (
 #pod Names of POD files to generate distribution F<README> text file. This is a multi-value option.
 #pod Empty values are ignored. Empty list disables generating F<README>file.
 #pod
-#pod C<ArrayRef[Str]>, optional, default value C<[ qw{
-#pod     doc/what.pod
-#pod     doc/why.pod
-#pod     doc/naming.pod
-#pod     doc/forms.pod
-#pod     doc/source.pod
-#pod     doc/distribution.pod
-#pod     doc/installing.pod
-#pod     doc/hacking.pod
-#pod     doc/documentation.pod
-#pod     doc/feedback.pod
-#pod     doc/glossary.pod
-#pod } ]>.
+#pod C<ArrayRef[Str]>, optional, default value C<[ 'doc/what.pod', 'doc/why.pod', 'doc/naming.pod', 'doc/forms.pod', 'doc/source.pod', 'doc/distribution.pod', 'doc/installing.pod', 'doc/hacking.pod', 'doc/documentation.pod', 'doc/feedback.pod', 'doc/glossary.pod' ]>.
 #pod
 #pod =cut
 
@@ -173,19 +120,7 @@ has readme => (
     lazy        => 1,
     default     => sub {
         my ( $self ) = @_;
-        my $readme = $self->payload->{ readme } // [ qw{
-    doc/what.pod
-    doc/why.pod
-    doc/naming.pod
-    doc/forms.pod
-    doc/source.pod
-    doc/distribution.pod
-    doc/installing.pod
-    doc/hacking.pod
-    doc/documentation.pod
-    doc/feedback.pod
-    doc/glossary.pod
-} ];
+        my $readme = $self->payload->{ readme } // [ 'doc/what.pod', 'doc/why.pod', 'doc/naming.pod', 'doc/forms.pod', 'doc/source.pod', 'doc/distribution.pod', 'doc/installing.pod', 'doc/hacking.pod', 'doc/documentation.pod', 'doc/feedback.pod', 'doc/glossary.pod' ];
         $readme = [ grep( { $_ ne  '' } @$readme ) ];   # Ignore empty items.
         if ( not @$readme ) {
             $readme = undef;
@@ -490,7 +425,7 @@ sub configure {
         #   File mungers
         #
 
-        [ 'Templates' => {
+        [ 'Templates' => { # REQUIRE: v0.5.0 for including `Dist::Zilla::File` objects.
             'templates' => [
                 '@Author::VDB/src doc',
                 @{ $self->templates // [] },
@@ -540,7 +475,7 @@ sub configure {
         #   Tests
         #
 
-        'Test::DiagINC',
+        [ 'Test::DiagINC' ],
 
         # Files
 
@@ -664,7 +599,6 @@ sub configure {
                             { phase => $phase, type => $type },
                             'IPC::System::Simple' => 0,
                         );
-
                     };
                 } );
             } ],
@@ -729,7 +663,7 @@ sub configure {
         #   Make sure the distro does not depend on unwanted modules. Unwanted module, for example,
         #   is `Data::Printer`. I use it often for debugging purposes and forget to remove
         #   debugging code.
-        [ 'Hook::BeforeRelease' => 'unwanted deps' => {
+        [ 'Hook::BeforeRelease' => 'unwanted deps' => { # REQUIRTE: HHH
             'hook' => [ q{
                 my @unwanted = (} . $self->_quote( $self->unwanted_modules ) . q{);
                 my %unwanted = map( { $_ => 1 } @unwanted );
@@ -992,7 +926,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.8.0, released on 2015-09-22 16:13 UTC.
+Version v0.8.1, released on 2015-09-25 20:00 UTC.
 
 =head1 WHAT?
 
@@ -1030,19 +964,7 @@ C<Str>, optional, default value C<doc/copying.pod>.
 Names of POD files to generate distribution F<README> text file. This is a multi-value option.
 Empty values are ignored. Empty list disables generating F<README>file.
 
-C<ArrayRef[Str]>, optional, default value C<[ qw{
-    doc/what.pod
-    doc/why.pod
-    doc/naming.pod
-    doc/forms.pod
-    doc/source.pod
-    doc/distribution.pod
-    doc/installing.pod
-    doc/hacking.pod
-    doc/documentation.pod
-    doc/feedback.pod
-    doc/glossary.pod
-} ]>.
+C<ArrayRef[Str]>, optional, default value C<[ 'doc/what.pod', 'doc/why.pod', 'doc/naming.pod', 'doc/forms.pod', 'doc/source.pod', 'doc/distribution.pod', 'doc/installing.pod', 'doc/hacking.pod', 'doc/documentation.pod', 'doc/feedback.pod', 'doc/glossary.pod' ]>.
 
 =head2 local_release
 
